==> kibana-7.17.13-darwin-aarch64.tar.gz: kibana-7.17.13-darwin-aarch64/src/core/server/saved_objects/migrationsv2/actions/catch_retryable_es_client_errors.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.catchRetryableEsClientErrors = void 0;
var Either = _interopRequireWildcard(require("fp-ts/lib/Either"));
var _elasticsearch = require("@elastic/elasticsearch");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */

const retryResponseStatuses = [503,
// ServiceUnavailable
401,
// AuthorizationException
403,
// AuthenticationException
408,
// RequestTimeout
410 // Gone
];

const catchRetryableEsClientErrors = e => {
  var _e$body, _e$body$error;
  if (e instanceof _elasticsearch.errors.NoLivingConnectionsError || e instanceof _elasticsearch.errors.ConnectionError || e instanceof _elasticsearch.errors.TimeoutError || e instanceof _elasticsearch.errors.ResponseError && (retryResponseStatuses.includes(e === null || e === void 0 ? void 0 : e.statusCode) ||
  // ES returns a 400 Bad Request when trying to close or delete an
  // index while snapshots are in progress. This should have been a 503
  // so once https://github.com/elastic/elasticsearch/issues/65883 is
  // fixed we can remove this.
  (e === null || e === void 0 ? void 0 : (_e$body = e.body) === null || _e$body === void 0 ? void 0 : (_e$body$error = _e$body.error) === null || _e$body$error === void 0 ? void 0 : _e$body$error.type) === 'snapshot_in_progress_exception')) {
    return Either.left({
      type: 'retryable_es_client_error',
      message: e === null || e === void 0 ? void 0 : e.message,
      error: e
    });
  } else {
    throw e;
  }
};
exports.catchRetryableEsClientErrors = catchRetryableEsClientErrors;

==> kibana-7.17.20-darwin-aarch64.tar.gz: kibana-7.17.20-darwin-aarch64/src/core/server/saved_objects/migrationsv2/actions/catch_retryable_es_client_errors.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.catchRetryableEsClientErrors = void 0;
var Either = _interopRequireWildcard(require("fp-ts/lib/Either"));
var _elasticsearch = require("@elastic/elasticsearch");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */

const retryResponseStatuses = [503,
// ServiceUnavailable
401,
// AuthorizationException
403,
// AuthenticationException
408,
// RequestTimeout
410 // Gone
];
const catchRetryableEsClientErrors = e => {
  var _e$body, _e$body$error;
  if (e instanceof _elasticsearch.errors.NoLivingConnectionsError || e instanceof _elasticsearch.errors.ConnectionError || e instanceof _elasticsearch.errors.TimeoutError || e instanceof _elasticsearch.errors.ResponseError && (retryResponseStatuses.includes(e === null || e === void 0 ? void 0 : e.statusCode) ||
  // ES returns a 400 Bad Request when trying to close or delete an
  // index while snapshots are in progress. This should have been a 503
  // so once https://github.com/elastic/elasticsearch/issues/65883 is
  // fixed we can remove this.
  (e === null || e === void 0 ? void 0 : (_e$body = e.body) === null || _e$body === void 0 ? void 0 : (_e$body$error = _e$body.error) === null || _e$body$error === void 0 ? void 0 : _e$body$error.type) === 'snapshot_in_progress_exception')) {
    return Either.left({
      type: 'retryable_es_client_error',
      message: e === null || e === void 0 ? void 0 : e.message,
      error: e
    });
  } else {
    throw e;
  }
};
exports.catchRetryableEsClientErrors = catchRetryableEsClientErrors;
